package java.awt.image;

public class AverageScaleFilter extends ReplicateScaleFilter {
   private static final ColorModel rgbmodel = ColorModel.getRGBdefault();
   private static final int neededHints = 6;
   private boolean passthrough;
   private float[] reds;
   private float[] greens;
   private float[] blues;
   private float[] alphas;
   private int savedy;
   private int savedyrem;

   public AverageScaleFilter(int var1, int var2) {
      super(var1, var2);
   }

   public void setHints(int var1) {
      this.passthrough = (var1 & 6) != 6;
      super.setHints(var1);
   }

   private void makeAccumBuffers() {
      this.reds = new float[super.destWidth];
      this.greens = new float[super.destWidth];
      this.blues = new float[super.destWidth];
      this.alphas = new float[super.destWidth];
   }

   private int[] calcRow() {
      float var1 = (float)super.srcWidth * (float)super.srcHeight;
      if (super.outpixbuf == null || !(super.outpixbuf instanceof int[])) {
         super.outpixbuf = new int[super.destWidth];
      }

      int[] var2 = (int[])super.outpixbuf;

      for(int var3 = 0; var3 < super.destWidth; ++var3) {
         int var4 = Math.round(this.alphas[var3] / var1);
         int var5 = Math.round(this.reds[var3] / var1);
         int var6 = Math.round(this.greens[var3] / var1);
         int var7 = Math.round(this.blues[var3] / var1);
         if (var4 < 0) {
            var4 = 0;
         } else if (var4 > 255) {
            var4 = 255;
         }

         if (var5 < 0) {
            var5 = 0;
         } else if (var5 > 255) {
            var5 = 255;
         }

         if (var6 < 0) {
            var6 = 0;
         } else if (var6 > 255) {
            var6 = 255;
         }

         if (var7 < 0) {
            var7 = 0;
         } else if (var7 > 255) {
            var7 = 255;
         }

         var2[var3] = var4 << 24 | var5 << 16 | var6 << 8 | var7;
      }

      return var2;
   }

   private void accumPixels(int var1, int var2, int var3, int var4, ColorModel var5, Object var6, int var7, int var8) {
      if (this.reds == null) {
         this.makeAccumBuffers();
      }

      int var9 = var2;
      int var10 = super.destHeight;
      int var11;
      int var12;
      if (var2 == 0) {
         var11 = 0;
         var12 = 0;
      } else {
         var11 = this.savedy;
         var12 = this.savedyrem;
      }

      while(var9 < var2 + var4) {
         if (var12 == 0) {
            for(int var14 = 0; var14 < super.destWidth; ++var14) {
               this.alphas[var14] = this.reds[var14] = this.greens[var14] = this.blues[var14] = 0.0F;
            }

            var12 = super.srcHeight;
         }

         int var13;
         if (var10 < var12) {
            var13 = var10;
         } else {
            var13 = var12;
         }

         int var24 = 0;
         int var15 = 0;
         int var16 = 0;
         int var17 = super.srcWidth;
         float var18 = 0.0F;
         float var19 = 0.0F;
         float var20 = 0.0F;
         float var21 = 0.0F;

         while(var24 < var3) {
            if (var16 == 0) {
               var16 = super.destWidth;
               int var22;
               if (var6 instanceof byte[]) {
                  var22 = ((byte[])var6)[var7 + var24] & 255;
               } else {
                  var22 = ((int[])var6)[var7 + var24];
               }

               var22 = var5.getRGB(var22);
               var18 = (float)(var22 >>> 24);
               var19 = (float)(var22 >> 16 & 255);
               var20 = (float)(var22 >> 8 & 255);
               var21 = (float)(var22 & 255);
            }

            int var26;
            if (var16 < var17) {
               var26 = var16;
            } else {
               var26 = var17;
            }

            float var23 = (float)var26 * (float)var13;
            float[] var10000 = this.alphas;
            var10000[var15] += var23 * var18;
            var10000 = this.reds;
            var10000[var15] += var23 * var19;
            var10000 = this.greens;
            var10000[var15] += var23 * var20;
            var10000 = this.blues;
            var10000[var15] += var23 * var21;
            if ((var16 -= var26) == 0) {
               ++var24;
            }

            if ((var17 -= var26) == 0) {
               ++var15;
               var17 = super.srcWidth;
            }
         }

         if ((var12 -= var13) == 0) {
            int[] var27 = this.calcRow();

            do {
               super.consumer.setPixels(0, var11, super.destWidth, 1, rgbmodel, var27, 0, super.destWidth);
               ++var11;
            } while((var10 -= var13) >= var13 && var13 == super.srcHeight);
         } else {
            var10 -= var13;
         }

         if (var10 == 0) {
            var10 = super.destHeight;
            ++var9;
            var7 += var8;
         }
      }

      this.savedyrem = var12;
      this.savedy = var11;
   }

   public void setPixels(int var1, int var2, int var3, int var4, ColorModel var5, byte[] var6, int var7, int var8) {
      if (this.passthrough) {
         super.setPixels(var1, var2, var3, var4, var5, var6, var7, var8);
      } else {
         this.accumPixels(var1, var2, var3, var4, var5, var6, var7, var8);
      }
   }

   public void setPixels(int var1, int var2, int var3, int var4, ColorModel var5, int[] var6, int var7, int var8) {
      if (this.passthrough) {
         super.setPixels(var1, var2, var3, var4, var5, var6, var7, var8);
      } else {
         this.accumPixels(var1, var2, var3, var4, var5, var6, var7, var8);
      }
   }
}
